@@ -1,4 +1,4 @@
-import { Range } from 'vscode-languageserver/node'
+import { Diagnostic, DiagnosticSeverity, Range } from 'vscode-languageserver/node'
 import { SyntaxNode } from 'web-tree-sitter'
 
 /**
@@ -56,3 +56,24 @@ export function findParent(
   }
   return null
 }
+
+export function getDiagnosticsForMissingNodes(node: SyntaxNode) {
+  const diagnostics: Diagnostic[] = []
+
+  forEach(node, (node) => {
+    if (node.isMissing()) {
+      diagnostics.push(
+        Diagnostic.create(
+          range(node),
+          `Syntax error: "${node.type}" missing`,
+          DiagnosticSeverity.Warning,
+          undefined,
+          'bash-language-server',
+        ),
+      )
+    }
+    return node.hasError()
+  })
+
+  return diagnostics
+}
